magneticalc.Validatable.Validatable

# ``magneticalc`.`Validatable`.`Validatable``

class documentation

`class Validatable(object):`

Known subclasses: `magneticalc.Field.Field`, `magneticalc.Metric.Metric`, `magneticalc.Parameters.Parameters`, `magneticalc.SamplingVolume.SamplingVolume`, `magneticalc.Wire.Wire`

Constructor: `Validatable()`

View In Hierarchy

Validatable class.

Method | `__init__` | Initializes a validatable object.
Method | `valid.setter` | No summary
Property | `valid` | True if valid, False if invalid
Instance Variable | `_valid` | Undocumented

def __init__(self):
overridden in `magneticalc.Field.Field`, `magneticalc.Metric.Metric`, `magneticalc.Parameters.Parameters`, `magneticalc.SamplingVolume.SamplingVolume`, `magneticalc.Wire.Wire`

Initializes a validatable object.

@valid.setter
def valid(self, valid: `bool`):

Parameters
valid: `bool` | True if valid, False if invalid

@property
valid: `bool` =

True if valid, False if invalid

_valid =

Undocumented